"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _awsSdk = require("aws-sdk");

var _bluebird = _interopRequireDefault(require("bluebird"));

var _highland = _interopRequireDefault(require("highland"));

/* eslint import/no-extraneous-dependencies: ["error", {"devDependencies": true}] */
_awsSdk.config.setPromisesDependency(_bluebird.default);

class Connector {
  constructor({
    debug,
    tableName,
    timeout = Number(process.env.DYNAMODB_TIMEOUT) || Number(process.env.TIMEOUT) || 1000
  }) {
    this.debug = debug;
    this.tableName = tableName ||
    /* istanbul ignore next */
    'undefined';
    this.db = new _awsSdk.DynamoDB.DocumentClient({
      httpOptions: {
        timeout // agent: sslAgent,

      },
      logger: {
        log:
        /* istanbul ignore next */
        msg => this.debug(msg)
      },
      convertEmptyValues: true
    });
  }

  update(inputParams) {
    const params = {
      TableName: this.tableName,
      ...inputParams
    };
    return this.db.update(params).promise().tap(this.debug).tapCatch(this.debug).catch(
    /* istanbul ignore next */
    err => {
      if (err.code === 'ConditionalCheckFailedException') {
        return {};
      }

      return _bluebird.default.reject(err);
    });
  }

  put(inputParams) {
    const params = {
      TableName: this.tableName,
      ...inputParams
    };
    return this.db.put(params).promise().tap(this.debug).tapCatch(this.debug);
  }

  batchGet(inputParams) {
    const params = { ...inputParams
    };
    return this.db.batchGet(params).promise().tap(this.debug).tapCatch(this.debug);
  }

  query(inputParams) {
    const params = {
      TableName: this.tableName,
      ...inputParams
    };
    let cursor;
    let itemsCount = 0;
    return (0, _highland.default)((push, next) => {
      params.ExclusiveStartKey = cursor;
      return this.db.query(params).promise().tap(this.debug).tapCatch(this.debug).then(data => {
        itemsCount += data.Items.length;

        if (data.LastEvaluatedKey && (!params.Limit || params.Limit && itemsCount < params.Limit)) {
          cursor = data.LastEvaluatedKey;
        } else {
          cursor = undefined;
        }

        data.Items.forEach(obj => {
          push(null, obj);
        });
      }).catch(
      /* istanbul ignore next */
      err => {
        push(err, null);
      }).finally(() => {
        if (cursor) {
          next();
        } else {
          push(null, _highland.default.nil);
        }
      });
    }).collect().toPromise(_bluebird.default);
  }

}

var _default = Connector;
exports.default = _default;