"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _awsSdk = require("aws-sdk");

var _bluebird = _interopRequireDefault(require("bluebird"));

/* eslint import/no-extraneous-dependencies: ["error", {"devDependencies": true}] */
_awsSdk.config.setPromisesDependency(_bluebird.default);
/**
 * All secrets are combined to reduce the number of calls
 * Secrets are transferred from a ci/cd pipeline's secured variables
 * to SecretsManager using the serverless-secrets-mgr-plugin
 */


class Connector {
  constructor({
    debug,
    secretId,
    timeout = Number(process.env.SECRETSMGR_TIMEOUT) || Number(process.env.TIMEOUT) || 1000
  }) {
    this.debug = debug;
    this.secretId = secretId;
    this.sm = new _awsSdk.SecretsManager({
      httpOptions: {
        timeout // agent: sslAgent,

      },
      logger: {
        log:
        /* istanbul ignore next */
        msg => this.debug(msg)
      }
    });
  }

  async get() {
    if (!this.secrets) {
      const params = {
        SecretId: this.secretId
      };
      this.secrets = await this.sm.getSecretValue(params).promise() // .tap(this.debug) // *** DO NOT LOGGING SECRETS ***
      .tapCatch(this.debug).then(data => Buffer.from(data.SecretString, 'base64').toString()).then(data => JSON.parse(data));
    }

    return this.secrets;
  }

}

var _default = Connector;
exports.default = _default;