"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.encryptEvent = exports.decryptEvent = void 0;

var _highland = _interopRequireDefault(require("highland"));

var _omit = _interopRequireDefault(require("lodash/omit"));

var _awsKmsEe = require("aws-kms-ee");

var _faults = require("./faults");

var _print = require("./print");

// -----------------------------------
// used in listeners
// -----------------------------------
const decryptEvent = ({
  debug = (0, _print.debug)('enc'),
  prefilter = () => false,
  eemField = 'eem',
  AES = true,
  parallel = Number(process.env.ENCRYPTION_PARALLEL) || Number(process.env.PARALLEL) || 8
} = {}) => {
  const decrypt = uow => {
    if (!uow.event[eemField] || !prefilter(uow)) {
      return (0, _highland.default)(Promise.resolve(uow));
    }

    const p = (0, _awsKmsEe.decryptObject)((0, _omit.default)(uow.event, eemField), { ...uow.event[eemField],
      AES
    }).tap(debug).tapCatch(debug).then(decryptResponse => ({ ...uow,
      decryptResponse,
      event: decryptResponse.object,
      undecryptedEvent: uow.event
    })).catch((0, _faults.rejectWithFault)(uow));
    return (0, _highland.default)(p); // wrap promise in a stream
  };

  return s => s.map(decrypt).parallel(parallel);
}; // -----------------------------------
// used in triggers prior to publish
// -----------------------------------


exports.decryptEvent = decryptEvent;

const encryptEvent = ({
  debug = (0, _print.debug)('enc'),
  eemField = 'eem',
  sourceField = 'event',
  targetField = 'event',
  eem,
  masterKeyAlias = process.env.MASTER_KEY_ALIAS,
  regions = process.env.KMS_REGIONS && process.env.KMS_REGIONS.split(','),
  AES = true,
  parallel = Number(process.env.ENCRYPTION_PARALLEL) || Number(process.env.PARALLEL) || 8
} = {}) => {
  const encrypt = uow => {
    if (!eem) {
      return (0, _highland.default)(Promise.resolve(uow));
    }

    const p = (0, _awsKmsEe.encryptObject)(uow[sourceField], {
      masterKeyAlias,
      regions,
      ...eem,
      // fields and overrides
      AES
    }).tap(debug).tapCatch(debug).then(encryptResponse => ({ ...uow,
      encryptResponse,
      [targetField]: { ...encryptResponse.encrypted,
        [eemField]: encryptResponse.metadata
      }
    })).catch((0, _faults.rejectWithFault)(uow));
    return (0, _highland.default)(p); // wrap promise in a stream
  };

  return s => s.map(encrypt).parallel(parallel);
};

exports.encryptEvent = encryptEvent;